@@ -1,5 +1,7 @@
+# import sys
+# print("path: " + str(sys.path))
 from django.conf.urls import patterns, url
-import views
+from usethis_bootstrap import views
 
 urlpatterns = patterns(
     '',
